<?php

namespace Asadi\Teacher\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Asadi\Teacher\Interfaces\TeacherRepositoryInterface;
use Asadi\Teacher\Repositories\Presenter\TeacherItemTransformer;

/**
 * Pubic API controller class.
 */
class TeacherPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Asadi\Teacher\Interfaces\TeacherRepositoryInterface $teacher
     *
     * @return type
     */
    public function __construct(TeacherRepositoryInterface $teacher)
    {
        $this->repository = $teacher;
        parent::__construct();
    }

    /**
     * Show teacher's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $teachers = $this->repository
            ->setPresenter('\\Asadi\\Teacher\\Repositories\\Presenter\\TeacherListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $teachers['code'] = 2000;
        return response()->json($teachers)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show teacher.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $teacher = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($teacher)) {
            $teacher         = $this->itemPresenter($module, new TeacherItemTransformer);
            $teacher['code'] = 2001;
            return response()->json($teacher)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
