<?php

namespace Asadi\Teacher\Http\Controllers;

use App\Http\Controllers\UserController as BaseController;
use Form;
use Asadi\Teacher\Http\Requests\TeacherRequest;
use Asadi\Teacher\Interfaces\TeacherRepositoryInterface;
use Asadi\Teacher\Models\Teacher;

class TeacherUserController extends BaseController
{
    /**
     * Initialize teacher controller.
     *
     * @param type TeacherRepositoryInterface $teacher
     *
     * @return type
     */
    public function __construct(TeacherRepositoryInterface $teacher)
    {
        $this->repository = $teacher;
        $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->pushCriteria(new \Asadi\Teacher\Repositories\Criteria\TeacherUserCriteria());
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(TeacherRequest $request)
    {
        $teachers = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('teacher::teacher.names'));

        return $this->theme->of('teacher::user.teacher.index', compact('teachers'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Teacher $teacher
     *
     * @return Response
     */
    public function show(TeacherRequest $request, Teacher $teacher)
    {
        Form::populate($teacher);

        return $this->theme->of('teacher::user.teacher.show', compact('teacher'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(TeacherRequest $request)
    {

        $teacher = $this->repository->newInstance([]);
        Form::populate($teacher);

        $this->theme->prependTitle(trans('teacher::teacher.names'));
        return $this->theme->of('teacher::user.teacher.create', compact('teacher'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TeacherRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $teacher = $this->repository->create($attributes);

            return redirect(trans_url('/user/teacher/teacher'))
                -> with('message', trans('messages.success.created', ['Module' => trans('teacher::teacher.name')]))
                -> with('code', 201);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Teacher $teacher
     *
     * @return Response
     */
    public function edit(TeacherRequest $request, Teacher $teacher)
    {

        Form::populate($teacher);
        $this->theme->prependTitle(trans('teacher::teacher.names'));

        return $this->theme->of('teacher::user.teacher.edit', compact('teacher'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Teacher $teacher
     *
     * @return Response
     */
    public function update(TeacherRequest $request, Teacher $teacher)
    {
        try {
            $this->repository->update($request->all(), $teacher->getRouteKey());

            return redirect(trans_url('/user/teacher/teacher'))
                ->with('message', trans('messages.success.updated', ['Module' => trans('teacher::teacher.name')]))
                ->with('code', 204);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(TeacherRequest $request, Teacher $teacher)
    {
        try {
            $this->repository->delete($teacher->getRouteKey());
            return redirect(trans_url('/user/teacher/teacher'))
                ->with('message', trans('messages.success.deleted', ['Module' => trans('teacher::teacher.name')]))
                ->with('code', 204);

        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
