<?php

namespace Asadi\Teacher\Policies;

use App\User;
use Asadi\Teacher\Models\Teacher;

class TeacherPolicy
{

    /**
     * Determine if the given user can view the teacher.
     *
     * @param User $user
     * @param Teacher $teacher
     *
     * @return bool
     */
    public function view(User $user, Teacher $teacher)
    {
        if ($user->canDo('teacher.teacher.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $teacher->user_id;
    }

    /**
     * Determine if the given user can create a teacher.
     *
     * @param User $user
     * @param Teacher $teacher
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('teacher.teacher.create');
    }

    /**
     * Determine if the given user can update the given teacher.
     *
     * @param User $user
     * @param Teacher $teacher
     *
     * @return bool
     */
    public function update(User $user, Teacher $teacher)
    {
        if ($user->canDo('teacher.teacher.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $teacher->user_id;
    }

    /**
     * Determine if the given user can delete the given teacher.
     *
     * @param User $user
     * @param Teacher $teacher
     *
     * @return bool
     */
    public function destroy(User $user, Teacher $teacher)
    {
        if ($user->canDo('teacher.teacher.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $teacher->user_id;
    }

    /**
     * Determine if the given user can verify the given teacher.
     *
     * @param User $user
     * @param Teacher $teacher
     *
     * @return bool
     */
    public function verify(User $user, Teacher $teacher)
    {
        if ($user->canDo('teacher.teacher.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('teacher.teacher.verify') 
        && $user->is('manager')
        && $teacher->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given teacher.
     *
     * @param User $user
     * @param Teacher $teacher
     *
     * @return bool
     */
    public function approve(User $user, Teacher $teacher)
    {
        if ($user->canDo('teacher.teacher.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
