<?php

namespace Asadi\Teacher\Workflow;

use Asadi\Teacher\Models\Teacher;
use Validator;

class TeacherValidator
{

    /**
     * Determine if the given teacher is valid for complete status.
     *
     * @param Teacher $teacher
     *
     * @return bool / Validator
     */
    public function complete(Teacher $teacher)
    {
        return Validator::make($teacher->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given teacher is valid for verify status.
     *
     * @param Teacher $teacher
     *
     * @return bool / Validator
     */
    public function verify(Teacher $teacher)
    {
        return Validator::make($teacher->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given teacher is valid for approve status.
     *
     * @param Teacher $teacher
     *
     * @return bool / Validator
     */
    public function approve(Teacher $teacher)
    {
        return Validator::make($teacher->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given teacher is valid for publish status.
     *
     * @param Teacher $teacher
     *
     * @return bool / Validator
     */
    public function publish(Teacher $teacher)
    {
        return Validator::make($teacher->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given teacher is valid for archive status.
     *
     * @param Teacher $teacher
     *
     * @return bool / Validator
     */
    public function archive(Teacher $teacher)
    {
        return Validator::make($teacher->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given teacher is valid for unpublish status.
     *
     * @param Teacher $teacher
     *
     * @return bool / Validator
     */
    public function unpublish(Teacher $teacher)
    {
        return Validator::make($teacher->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
